<?php

namespace Reinaldo\Teste00pkg\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Reinaldo\Teste00pkg\Models\Comercial;

class ComercialPolicy
{

    /**
     * Determine if the given user can view the comercial.
     *
     * @param UserPolicyInterface $authUser
     * @param Comercial $comercial
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Comercial $comercial)
    {
        if ($authUser->canDo('teste00pkg.comercial.view') && $authUser->isAdmin()) {
            return true;
        }

        return $comercial->user_id == user_id() && $comercial->user_type == user_type();
    }

    /**
     * Determine if the given user can create a comercial.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('teste00pkg.comercial.create');
    }

    /**
     * Determine if the given user can update the given comercial.
     *
     * @param UserPolicyInterface $authUser
     * @param Comercial $comercial
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Comercial $comercial)
    {
        if ($authUser->canDo('teste00pkg.comercial.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $comercial->user_id == user_id() && $comercial->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given comercial.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Comercial $comercial)
    {
        return $comercial->user_id == user_id() && $comercial->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given comercial.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Comercial $comercial)
    {
        if ($authUser->canDo('teste00pkg.comercial.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given comercial.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Comercial $comercial)
    {
        if ($authUser->canDo('teste00pkg.comercial.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
